# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetTwingateUsersResult',
    'AwaitableGetTwingateUsersResult',
    'get_twingate_users',
    'get_twingate_users_output',
]

@pulumi.output_type
class GetTwingateUsersResult:
    """
    A collection of values returned by getTwingateUsers.
    """
    def __init__(__self__, email=None, email_contains=None, email_exclude=None, email_prefix=None, email_regexp=None, email_suffix=None, first_name=None, first_name_contains=None, first_name_exclude=None, first_name_prefix=None, first_name_regexp=None, first_name_suffix=None, id=None, last_name=None, last_name_contains=None, last_name_exclude=None, last_name_prefix=None, last_name_regexp=None, last_name_suffix=None, roles=None, users=None):
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if email_contains and not isinstance(email_contains, str):
            raise TypeError("Expected argument 'email_contains' to be a str")
        pulumi.set(__self__, "email_contains", email_contains)
        if email_exclude and not isinstance(email_exclude, str):
            raise TypeError("Expected argument 'email_exclude' to be a str")
        pulumi.set(__self__, "email_exclude", email_exclude)
        if email_prefix and not isinstance(email_prefix, str):
            raise TypeError("Expected argument 'email_prefix' to be a str")
        pulumi.set(__self__, "email_prefix", email_prefix)
        if email_regexp and not isinstance(email_regexp, str):
            raise TypeError("Expected argument 'email_regexp' to be a str")
        pulumi.set(__self__, "email_regexp", email_regexp)
        if email_suffix and not isinstance(email_suffix, str):
            raise TypeError("Expected argument 'email_suffix' to be a str")
        pulumi.set(__self__, "email_suffix", email_suffix)
        if first_name and not isinstance(first_name, str):
            raise TypeError("Expected argument 'first_name' to be a str")
        pulumi.set(__self__, "first_name", first_name)
        if first_name_contains and not isinstance(first_name_contains, str):
            raise TypeError("Expected argument 'first_name_contains' to be a str")
        pulumi.set(__self__, "first_name_contains", first_name_contains)
        if first_name_exclude and not isinstance(first_name_exclude, str):
            raise TypeError("Expected argument 'first_name_exclude' to be a str")
        pulumi.set(__self__, "first_name_exclude", first_name_exclude)
        if first_name_prefix and not isinstance(first_name_prefix, str):
            raise TypeError("Expected argument 'first_name_prefix' to be a str")
        pulumi.set(__self__, "first_name_prefix", first_name_prefix)
        if first_name_regexp and not isinstance(first_name_regexp, str):
            raise TypeError("Expected argument 'first_name_regexp' to be a str")
        pulumi.set(__self__, "first_name_regexp", first_name_regexp)
        if first_name_suffix and not isinstance(first_name_suffix, str):
            raise TypeError("Expected argument 'first_name_suffix' to be a str")
        pulumi.set(__self__, "first_name_suffix", first_name_suffix)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_name and not isinstance(last_name, str):
            raise TypeError("Expected argument 'last_name' to be a str")
        pulumi.set(__self__, "last_name", last_name)
        if last_name_contains and not isinstance(last_name_contains, str):
            raise TypeError("Expected argument 'last_name_contains' to be a str")
        pulumi.set(__self__, "last_name_contains", last_name_contains)
        if last_name_exclude and not isinstance(last_name_exclude, str):
            raise TypeError("Expected argument 'last_name_exclude' to be a str")
        pulumi.set(__self__, "last_name_exclude", last_name_exclude)
        if last_name_prefix and not isinstance(last_name_prefix, str):
            raise TypeError("Expected argument 'last_name_prefix' to be a str")
        pulumi.set(__self__, "last_name_prefix", last_name_prefix)
        if last_name_regexp and not isinstance(last_name_regexp, str):
            raise TypeError("Expected argument 'last_name_regexp' to be a str")
        pulumi.set(__self__, "last_name_regexp", last_name_regexp)
        if last_name_suffix and not isinstance(last_name_suffix, str):
            raise TypeError("Expected argument 'last_name_suffix' to be a str")
        pulumi.set(__self__, "last_name_suffix", last_name_suffix)
        if roles and not isinstance(roles, list):
            raise TypeError("Expected argument 'roles' to be a list")
        pulumi.set(__self__, "roles", roles)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def email(self) -> Optional[str]:
        """
        Returns only users that exactly match this email.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="emailContains")
    def email_contains(self) -> Optional[str]:
        """
        Match when the value exist in the email of the user.
        """
        return pulumi.get(self, "email_contains")

    @property
    @pulumi.getter(name="emailExclude")
    def email_exclude(self) -> Optional[str]:
        """
        Match when the value does not exist in the email of the user.
        """
        return pulumi.get(self, "email_exclude")

    @property
    @pulumi.getter(name="emailPrefix")
    def email_prefix(self) -> Optional[str]:
        """
        The email of the user must start with the value.
        """
        return pulumi.get(self, "email_prefix")

    @property
    @pulumi.getter(name="emailRegexp")
    def email_regexp(self) -> Optional[str]:
        """
        The regular expression match of the email of the user.
        """
        return pulumi.get(self, "email_regexp")

    @property
    @pulumi.getter(name="emailSuffix")
    def email_suffix(self) -> Optional[str]:
        """
        The email of the user must end with the value.
        """
        return pulumi.get(self, "email_suffix")

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[str]:
        """
        Returns only users that exactly match the first name.
        """
        return pulumi.get(self, "first_name")

    @property
    @pulumi.getter(name="firstNameContains")
    def first_name_contains(self) -> Optional[str]:
        """
        Match when the value exist in the first name of the user.
        """
        return pulumi.get(self, "first_name_contains")

    @property
    @pulumi.getter(name="firstNameExclude")
    def first_name_exclude(self) -> Optional[str]:
        """
        Match when the value does not exist in the first name of the user.
        """
        return pulumi.get(self, "first_name_exclude")

    @property
    @pulumi.getter(name="firstNamePrefix")
    def first_name_prefix(self) -> Optional[str]:
        """
        The first name of the user must start with the value.
        """
        return pulumi.get(self, "first_name_prefix")

    @property
    @pulumi.getter(name="firstNameRegexp")
    def first_name_regexp(self) -> Optional[str]:
        """
        The regular expression match of the first name of the user.
        """
        return pulumi.get(self, "first_name_regexp")

    @property
    @pulumi.getter(name="firstNameSuffix")
    def first_name_suffix(self) -> Optional[str]:
        """
        The first name of the user must end with the value.
        """
        return pulumi.get(self, "first_name_suffix")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[str]:
        """
        Returns only users that exactly match the last name.
        """
        return pulumi.get(self, "last_name")

    @property
    @pulumi.getter(name="lastNameContains")
    def last_name_contains(self) -> Optional[str]:
        """
        Match when the value exist in the last name of the user.
        """
        return pulumi.get(self, "last_name_contains")

    @property
    @pulumi.getter(name="lastNameExclude")
    def last_name_exclude(self) -> Optional[str]:
        """
        Match when the value does not exist in the last name of the user.
        """
        return pulumi.get(self, "last_name_exclude")

    @property
    @pulumi.getter(name="lastNamePrefix")
    def last_name_prefix(self) -> Optional[str]:
        """
        The last name of the user must start with the value.
        """
        return pulumi.get(self, "last_name_prefix")

    @property
    @pulumi.getter(name="lastNameRegexp")
    def last_name_regexp(self) -> Optional[str]:
        """
        The regular expression match of the last name of the user.
        """
        return pulumi.get(self, "last_name_regexp")

    @property
    @pulumi.getter(name="lastNameSuffix")
    def last_name_suffix(self) -> Optional[str]:
        """
        The last name of the user must end with the value.
        """
        return pulumi.get(self, "last_name_suffix")

    @property
    @pulumi.getter
    def roles(self) -> Optional[Sequence[str]]:
        """
        Returns users that match a list of roles. Valid roles: `ADMIN`, `DEVOPS`, `SUPPORT`, `MEMBER`.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter
    def users(self) -> Sequence['outputs.GetTwingateUsersUserResult']:
        return pulumi.get(self, "users")


class AwaitableGetTwingateUsersResult(GetTwingateUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTwingateUsersResult(
            email=self.email,
            email_contains=self.email_contains,
            email_exclude=self.email_exclude,
            email_prefix=self.email_prefix,
            email_regexp=self.email_regexp,
            email_suffix=self.email_suffix,
            first_name=self.first_name,
            first_name_contains=self.first_name_contains,
            first_name_exclude=self.first_name_exclude,
            first_name_prefix=self.first_name_prefix,
            first_name_regexp=self.first_name_regexp,
            first_name_suffix=self.first_name_suffix,
            id=self.id,
            last_name=self.last_name,
            last_name_contains=self.last_name_contains,
            last_name_exclude=self.last_name_exclude,
            last_name_prefix=self.last_name_prefix,
            last_name_regexp=self.last_name_regexp,
            last_name_suffix=self.last_name_suffix,
            roles=self.roles,
            users=self.users)


def get_twingate_users(email: Optional[str] = None,
                       email_contains: Optional[str] = None,
                       email_exclude: Optional[str] = None,
                       email_prefix: Optional[str] = None,
                       email_regexp: Optional[str] = None,
                       email_suffix: Optional[str] = None,
                       first_name: Optional[str] = None,
                       first_name_contains: Optional[str] = None,
                       first_name_exclude: Optional[str] = None,
                       first_name_prefix: Optional[str] = None,
                       first_name_regexp: Optional[str] = None,
                       first_name_suffix: Optional[str] = None,
                       last_name: Optional[str] = None,
                       last_name_contains: Optional[str] = None,
                       last_name_exclude: Optional[str] = None,
                       last_name_prefix: Optional[str] = None,
                       last_name_regexp: Optional[str] = None,
                       last_name_suffix: Optional[str] = None,
                       roles: Optional[Sequence[str]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTwingateUsersResult:
    """
    Users in Twingate can be given access to Twingate Resources and may either be added manually or automatically synchronized with a 3rd party identity provider. For more information, see Twingate's [documentation](https://docs.twingate.com/docs/users).

    ## Example Usage

    <!--Start PulumiCodeChooser -->
    ```python
    import pulumi
    import pulumi_twingate as twingate

    all = twingate.get_twingate_users()
    ```
    <!--End PulumiCodeChooser -->


    :param str email: The email address of the User
    :param str email_contains: Match when the value exist in the email of the user.
    :param str email_exclude: Match when the value does not exist in the email of the user.
    :param str email_prefix: The email of the user must start with the value.
    :param str email_regexp: The regular expression match of the email of the user.
    :param str email_suffix: The email of the user must end with the value.
    :param str first_name: The first name of the User
    :param str first_name_contains: Match when the value exist in the first name of the user.
    :param str first_name_exclude: Match when the value does not exist in the first name of the user.
    :param str first_name_prefix: The first name of the user must start with the value.
    :param str first_name_regexp: The regular expression match of the first name of the user.
    :param str first_name_suffix: The first name of the user must end with the value.
    :param str last_name: The last name of the User
    :param str last_name_contains: Match when the value exist in the last name of the user.
    :param str last_name_exclude: Match when the value does not exist in the last name of the user.
    :param str last_name_prefix: The last name of the user must start with the value.
    :param str last_name_regexp: The regular expression match of the last name of the user.
    :param str last_name_suffix: The last name of the user must end with the value.
    :param Sequence[str] roles: Returns users that match a list of roles. Valid roles: `ADMIN`, `DEVOPS`, `SUPPORT`, `MEMBER`.
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['emailContains'] = email_contains
    __args__['emailExclude'] = email_exclude
    __args__['emailPrefix'] = email_prefix
    __args__['emailRegexp'] = email_regexp
    __args__['emailSuffix'] = email_suffix
    __args__['firstName'] = first_name
    __args__['firstNameContains'] = first_name_contains
    __args__['firstNameExclude'] = first_name_exclude
    __args__['firstNamePrefix'] = first_name_prefix
    __args__['firstNameRegexp'] = first_name_regexp
    __args__['firstNameSuffix'] = first_name_suffix
    __args__['lastName'] = last_name
    __args__['lastNameContains'] = last_name_contains
    __args__['lastNameExclude'] = last_name_exclude
    __args__['lastNamePrefix'] = last_name_prefix
    __args__['lastNameRegexp'] = last_name_regexp
    __args__['lastNameSuffix'] = last_name_suffix
    __args__['roles'] = roles
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('twingate:index/getTwingateUsers:getTwingateUsers', __args__, opts=opts, typ=GetTwingateUsersResult).value

    return AwaitableGetTwingateUsersResult(
        email=pulumi.get(__ret__, 'email'),
        email_contains=pulumi.get(__ret__, 'email_contains'),
        email_exclude=pulumi.get(__ret__, 'email_exclude'),
        email_prefix=pulumi.get(__ret__, 'email_prefix'),
        email_regexp=pulumi.get(__ret__, 'email_regexp'),
        email_suffix=pulumi.get(__ret__, 'email_suffix'),
        first_name=pulumi.get(__ret__, 'first_name'),
        first_name_contains=pulumi.get(__ret__, 'first_name_contains'),
        first_name_exclude=pulumi.get(__ret__, 'first_name_exclude'),
        first_name_prefix=pulumi.get(__ret__, 'first_name_prefix'),
        first_name_regexp=pulumi.get(__ret__, 'first_name_regexp'),
        first_name_suffix=pulumi.get(__ret__, 'first_name_suffix'),
        id=pulumi.get(__ret__, 'id'),
        last_name=pulumi.get(__ret__, 'last_name'),
        last_name_contains=pulumi.get(__ret__, 'last_name_contains'),
        last_name_exclude=pulumi.get(__ret__, 'last_name_exclude'),
        last_name_prefix=pulumi.get(__ret__, 'last_name_prefix'),
        last_name_regexp=pulumi.get(__ret__, 'last_name_regexp'),
        last_name_suffix=pulumi.get(__ret__, 'last_name_suffix'),
        roles=pulumi.get(__ret__, 'roles'),
        users=pulumi.get(__ret__, 'users'))


@_utilities.lift_output_func(get_twingate_users)
def get_twingate_users_output(email: Optional[pulumi.Input[Optional[str]]] = None,
                              email_contains: Optional[pulumi.Input[Optional[str]]] = None,
                              email_exclude: Optional[pulumi.Input[Optional[str]]] = None,
                              email_prefix: Optional[pulumi.Input[Optional[str]]] = None,
                              email_regexp: Optional[pulumi.Input[Optional[str]]] = None,
                              email_suffix: Optional[pulumi.Input[Optional[str]]] = None,
                              first_name: Optional[pulumi.Input[Optional[str]]] = None,
                              first_name_contains: Optional[pulumi.Input[Optional[str]]] = None,
                              first_name_exclude: Optional[pulumi.Input[Optional[str]]] = None,
                              first_name_prefix: Optional[pulumi.Input[Optional[str]]] = None,
                              first_name_regexp: Optional[pulumi.Input[Optional[str]]] = None,
                              first_name_suffix: Optional[pulumi.Input[Optional[str]]] = None,
                              last_name: Optional[pulumi.Input[Optional[str]]] = None,
                              last_name_contains: Optional[pulumi.Input[Optional[str]]] = None,
                              last_name_exclude: Optional[pulumi.Input[Optional[str]]] = None,
                              last_name_prefix: Optional[pulumi.Input[Optional[str]]] = None,
                              last_name_regexp: Optional[pulumi.Input[Optional[str]]] = None,
                              last_name_suffix: Optional[pulumi.Input[Optional[str]]] = None,
                              roles: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTwingateUsersResult]:
    """
    Users in Twingate can be given access to Twingate Resources and may either be added manually or automatically synchronized with a 3rd party identity provider. For more information, see Twingate's [documentation](https://docs.twingate.com/docs/users).

    ## Example Usage

    <!--Start PulumiCodeChooser -->
    ```python
    import pulumi
    import pulumi_twingate as twingate

    all = twingate.get_twingate_users()
    ```
    <!--End PulumiCodeChooser -->


    :param str email: The email address of the User
    :param str email_contains: Match when the value exist in the email of the user.
    :param str email_exclude: Match when the value does not exist in the email of the user.
    :param str email_prefix: The email of the user must start with the value.
    :param str email_regexp: The regular expression match of the email of the user.
    :param str email_suffix: The email of the user must end with the value.
    :param str first_name: The first name of the User
    :param str first_name_contains: Match when the value exist in the first name of the user.
    :param str first_name_exclude: Match when the value does not exist in the first name of the user.
    :param str first_name_prefix: The first name of the user must start with the value.
    :param str first_name_regexp: The regular expression match of the first name of the user.
    :param str first_name_suffix: The first name of the user must end with the value.
    :param str last_name: The last name of the User
    :param str last_name_contains: Match when the value exist in the last name of the user.
    :param str last_name_exclude: Match when the value does not exist in the last name of the user.
    :param str last_name_prefix: The last name of the user must start with the value.
    :param str last_name_regexp: The regular expression match of the last name of the user.
    :param str last_name_suffix: The last name of the user must end with the value.
    :param Sequence[str] roles: Returns users that match a list of roles. Valid roles: `ADMIN`, `DEVOPS`, `SUPPORT`, `MEMBER`.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['TwingateRemoteNetworkArgs', 'TwingateRemoteNetwork']

@pulumi.input_type
class TwingateRemoteNetworkArgs:
    def __init__(__self__, *,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a TwingateRemoteNetwork resource.
        :param pulumi.Input[str] location: The location of the Remote Network. Must be one of the following: AWS, AZURE, GOOGLE*CLOUD, ON*PREMISE, OTHER.
        :param pulumi.Input[str] name: The name of the Remote Network
        """
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The location of the Remote Network. Must be one of the following: AWS, AZURE, GOOGLE*CLOUD, ON*PREMISE, OTHER.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Remote Network
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _TwingateRemoteNetworkState:
    def __init__(__self__, *,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering TwingateRemoteNetwork resources.
        :param pulumi.Input[str] location: The location of the Remote Network. Must be one of the following: AWS, AZURE, GOOGLE*CLOUD, ON*PREMISE, OTHER.
        :param pulumi.Input[str] name: The name of the Remote Network
        """
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The location of the Remote Network. Must be one of the following: AWS, AZURE, GOOGLE*CLOUD, ON*PREMISE, OTHER.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Remote Network
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class TwingateRemoteNetwork(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        A Remote Network represents a single private network in Twingate that can have one or more Connectors and Resources assigned to it. You must create a Remote Network before creating Resources and Connectors that belong to it. For more information, see Twingate's [documentation](https://docs.twingate.com/docs/remote-networks).

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import emailbob_twingate as twingate

        aws_network = twingate.TwingateRemoteNetwork("awsNetwork")
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        ```sh
        $ pulumi import twingate:index/twingateRemoteNetwork:TwingateRemoteNetwork network UmVtb3RlTmV0d29zaipgMKIkNg==
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] location: The location of the Remote Network. Must be one of the following: AWS, AZURE, GOOGLE*CLOUD, ON*PREMISE, OTHER.
        :param pulumi.Input[str] name: The name of the Remote Network
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[TwingateRemoteNetworkArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A Remote Network represents a single private network in Twingate that can have one or more Connectors and Resources assigned to it. You must create a Remote Network before creating Resources and Connectors that belong to it. For more information, see Twingate's [documentation](https://docs.twingate.com/docs/remote-networks).

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import emailbob_twingate as twingate

        aws_network = twingate.TwingateRemoteNetwork("awsNetwork")
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        ```sh
        $ pulumi import twingate:index/twingateRemoteNetwork:TwingateRemoteNetwork network UmVtb3RlTmV0d29zaipgMKIkNg==
        ```

        :param str resource_name: The name of the resource.
        :param TwingateRemoteNetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TwingateRemoteNetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TwingateRemoteNetworkArgs.__new__(TwingateRemoteNetworkArgs)

            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
        super(TwingateRemoteNetwork, __self__).__init__(
            'twingate:index/twingateRemoteNetwork:TwingateRemoteNetwork',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            location: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'TwingateRemoteNetwork':
        """
        Get an existing TwingateRemoteNetwork resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] location: The location of the Remote Network. Must be one of the following: AWS, AZURE, GOOGLE*CLOUD, ON*PREMISE, OTHER.
        :param pulumi.Input[str] name: The name of the Remote Network
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TwingateRemoteNetworkState.__new__(_TwingateRemoteNetworkState)

        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        return TwingateRemoteNetwork(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        The location of the Remote Network. Must be one of the following: AWS, AZURE, GOOGLE*CLOUD, ON*PREMISE, OTHER.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Remote Network
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetTwingateConnectorsResult',
    'AwaitableGetTwingateConnectorsResult',
    'get_twingate_connectors',
    'get_twingate_connectors_output',
]

@pulumi.output_type
class GetTwingateConnectorsResult:
    """
    A collection of values returned by getTwingateConnectors.
    """
    def __init__(__self__, connectors=None, id=None, name=None, name_contains=None, name_exclude=None, name_prefix=None, name_regexp=None, name_suffix=None):
        if connectors and not isinstance(connectors, list):
            raise TypeError("Expected argument 'connectors' to be a list")
        pulumi.set(__self__, "connectors", connectors)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if name_contains and not isinstance(name_contains, str):
            raise TypeError("Expected argument 'name_contains' to be a str")
        pulumi.set(__self__, "name_contains", name_contains)
        if name_exclude and not isinstance(name_exclude, str):
            raise TypeError("Expected argument 'name_exclude' to be a str")
        pulumi.set(__self__, "name_exclude", name_exclude)
        if name_prefix and not isinstance(name_prefix, str):
            raise TypeError("Expected argument 'name_prefix' to be a str")
        pulumi.set(__self__, "name_prefix", name_prefix)
        if name_regexp and not isinstance(name_regexp, str):
            raise TypeError("Expected argument 'name_regexp' to be a str")
        pulumi.set(__self__, "name_regexp", name_regexp)
        if name_suffix and not isinstance(name_suffix, str):
            raise TypeError("Expected argument 'name_suffix' to be a str")
        pulumi.set(__self__, "name_suffix", name_suffix)

    @property
    @pulumi.getter
    def connectors(self) -> Sequence['outputs.GetTwingateConnectorsConnectorResult']:
        """
        List of Connectors
        """
        return pulumi.get(self, "connectors")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Returns only connectors that exactly match this name. If no options are passed it will return all connectors. Only one option can be used at a time.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nameContains")
    def name_contains(self) -> Optional[str]:
        """
        Match when the value exist in the name of the connector.
        """
        return pulumi.get(self, "name_contains")

    @property
    @pulumi.getter(name="nameExclude")
    def name_exclude(self) -> Optional[str]:
        """
        Match when the exact value does not exist in the name of the connector.
        """
        return pulumi.get(self, "name_exclude")

    @property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> Optional[str]:
        """
        The name of the connector must start with the value.
        """
        return pulumi.get(self, "name_prefix")

    @property
    @pulumi.getter(name="nameRegexp")
    def name_regexp(self) -> Optional[str]:
        """
        The regular expression match of the name of the connector.
        """
        return pulumi.get(self, "name_regexp")

    @property
    @pulumi.getter(name="nameSuffix")
    def name_suffix(self) -> Optional[str]:
        """
        The name of the connector must end with the value.
        """
        return pulumi.get(self, "name_suffix")


class AwaitableGetTwingateConnectorsResult(GetTwingateConnectorsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTwingateConnectorsResult(
            connectors=self.connectors,
            id=self.id,
            name=self.name,
            name_contains=self.name_contains,
            name_exclude=self.name_exclude,
            name_prefix=self.name_prefix,
            name_regexp=self.name_regexp,
            name_suffix=self.name_suffix)


def get_twingate_connectors(name: Optional[str] = None,
                            name_contains: Optional[str] = None,
                            name_exclude: Optional[str] = None,
                            name_prefix: Optional[str] = None,
                            name_regexp: Optional[str] = None,
                            name_suffix: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTwingateConnectorsResult:
    """
    Connectors provide connectivity to Remote Networks. For more information, see Twingate's [documentation](https://docs.twingate.com/docs/understanding-access-nodes).

    ## Example Usage

    <!--Start PulumiCodeChooser -->
    ```python
    import pulumi
    import pulumi_twingate as twingate

    all = twingate.get_twingate_connectors(name="<your connector's name>")
    ```
    <!--End PulumiCodeChooser -->


    :param str name: The Name of the Connector.
    :param str name_contains: Match when the value exist in the name of the connector.
    :param str name_exclude: Match when the exact value does not exist in the name of the connector.
    :param str name_prefix: The name of the connector must start with the value.
    :param str name_regexp: The regular expression match of the name of the connector.
    :param str name_suffix: The name of the connector must end with the value.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['nameContains'] = name_contains
    __args__['nameExclude'] = name_exclude
    __args__['namePrefix'] = name_prefix
    __args__['nameRegexp'] = name_regexp
    __args__['nameSuffix'] = name_suffix
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('twingate:index/getTwingateConnectors:getTwingateConnectors', __args__, opts=opts, typ=GetTwingateConnectorsResult).value

    return AwaitableGetTwingateConnectorsResult(
        connectors=pulumi.get(__ret__, 'connectors'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        name_contains=pulumi.get(__ret__, 'name_contains'),
        name_exclude=pulumi.get(__ret__, 'name_exclude'),
        name_prefix=pulumi.get(__ret__, 'name_prefix'),
        name_regexp=pulumi.get(__ret__, 'name_regexp'),
        name_suffix=pulumi.get(__ret__, 'name_suffix'))


@_utilities.lift_output_func(get_twingate_connectors)
def get_twingate_connectors_output(name: Optional[pulumi.Input[Optional[str]]] = None,
                                   name_contains: Optional[pulumi.Input[Optional[str]]] = None,
                                   name_exclude: Optional[pulumi.Input[Optional[str]]] = None,
                                   name_prefix: Optional[pulumi.Input[Optional[str]]] = None,
                                   name_regexp: Optional[pulumi.Input[Optional[str]]] = None,
                                   name_suffix: Optional[pulumi.Input[Optional[str]]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTwingateConnectorsResult]:
    """
    Connectors provide connectivity to Remote Networks. For more information, see Twingate's [documentation](https://docs.twingate.com/docs/understanding-access-nodes).

    ## Example Usage

    <!--Start PulumiCodeChooser -->
    ```python
    import pulumi
    import pulumi_twingate as twingate

    all = twingate.get_twingate_connectors(name="<your connector's name>")
    ```
    <!--End PulumiCodeChooser -->


    :param str name: The Name of the Connector.
    :param str name_contains: Match when the value exist in the name of the connector.
    :param str name_exclude: Match when the exact value does not exist in the name of the connector.
    :param str name_prefix: The name of the connector must start with the value.
    :param str name_regexp: The regular expression match of the name of the connector.
    :param str name_suffix: The name of the connector must end with the value.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['TwingateServiceAccountArgs', 'TwingateServiceAccount']

@pulumi.input_type
class TwingateServiceAccountArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a TwingateServiceAccount resource.
        :param pulumi.Input[str] name: The name of the Service Account in Twingate
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Service Account in Twingate
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _TwingateServiceAccountState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering TwingateServiceAccount resources.
        :param pulumi.Input[str] name: The name of the Service Account in Twingate
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Service Account in Twingate
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class TwingateServiceAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Service Accounts offer a way to provide programmatic, centrally-controlled, and consistent access controls.

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import emailbob_twingate as twingate

        github_actions_prod = twingate.TwingateServiceAccount("githubActionsProd")
        ```
        <!--End PulumiCodeChooser -->

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the Service Account in Twingate
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[TwingateServiceAccountArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Service Accounts offer a way to provide programmatic, centrally-controlled, and consistent access controls.

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import emailbob_twingate as twingate

        github_actions_prod = twingate.TwingateServiceAccount("githubActionsProd")
        ```
        <!--End PulumiCodeChooser -->

        :param str resource_name: The name of the resource.
        :param TwingateServiceAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TwingateServiceAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TwingateServiceAccountArgs.__new__(TwingateServiceAccountArgs)

            __props__.__dict__["name"] = name
        super(TwingateServiceAccount, __self__).__init__(
            'twingate:index/twingateServiceAccount:TwingateServiceAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'TwingateServiceAccount':
        """
        Get an existing TwingateServiceAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the Service Account in Twingate
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TwingateServiceAccountState.__new__(_TwingateServiceAccountState)

        __props__.__dict__["name"] = name
        return TwingateServiceAccount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Service Account in Twingate
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetTwingateResourcesResult',
    'AwaitableGetTwingateResourcesResult',
    'get_twingate_resources',
    'get_twingate_resources_output',
]

@pulumi.output_type
class GetTwingateResourcesResult:
    """
    A collection of values returned by getTwingateResources.
    """
    def __init__(__self__, id=None, name=None, name_contains=None, name_exclude=None, name_prefix=None, name_regexp=None, name_suffix=None, resources=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if name_contains and not isinstance(name_contains, str):
            raise TypeError("Expected argument 'name_contains' to be a str")
        pulumi.set(__self__, "name_contains", name_contains)
        if name_exclude and not isinstance(name_exclude, str):
            raise TypeError("Expected argument 'name_exclude' to be a str")
        pulumi.set(__self__, "name_exclude", name_exclude)
        if name_prefix and not isinstance(name_prefix, str):
            raise TypeError("Expected argument 'name_prefix' to be a str")
        pulumi.set(__self__, "name_prefix", name_prefix)
        if name_regexp and not isinstance(name_regexp, str):
            raise TypeError("Expected argument 'name_regexp' to be a str")
        pulumi.set(__self__, "name_regexp", name_regexp)
        if name_suffix and not isinstance(name_suffix, str):
            raise TypeError("Expected argument 'name_suffix' to be a str")
        pulumi.set(__self__, "name_suffix", name_suffix)
        if resources and not isinstance(resources, list):
            raise TypeError("Expected argument 'resources' to be a list")
        pulumi.set(__self__, "resources", resources)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Returns only resources that exactly match this name. If no options are passed it will return all resources. Only one option can be used at a time.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nameContains")
    def name_contains(self) -> Optional[str]:
        """
        Match when the value exist in the name of the resource.
        """
        return pulumi.get(self, "name_contains")

    @property
    @pulumi.getter(name="nameExclude")
    def name_exclude(self) -> Optional[str]:
        """
        Match when the exact value does not exist in the name of the resource.
        """
        return pulumi.get(self, "name_exclude")

    @property
    @pulumi.getter(name="namePrefix")
    def name_prefix(self) -> Optional[str]:
        """
        The name of the resource must start with the value.
        """
        return pulumi.get(self, "name_prefix")

    @property
    @pulumi.getter(name="nameRegexp")
    def name_regexp(self) -> Optional[str]:
        """
        The regular expression match of the name of the resource.
        """
        return pulumi.get(self, "name_regexp")

    @property
    @pulumi.getter(name="nameSuffix")
    def name_suffix(self) -> Optional[str]:
        """
        The name of the resource must end with the value.
        """
        return pulumi.get(self, "name_suffix")

    @property
    @pulumi.getter
    def resources(self) -> Sequence['outputs.GetTwingateResourcesResourceResult']:
        """
        List of Resources
        """
        return pulumi.get(self, "resources")


class AwaitableGetTwingateResourcesResult(GetTwingateResourcesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTwingateResourcesResult(
            id=self.id,
            name=self.name,
            name_contains=self.name_contains,
            name_exclude=self.name_exclude,
            name_prefix=self.name_prefix,
            name_regexp=self.name_regexp,
            name_suffix=self.name_suffix,
            resources=self.resources)


def get_twingate_resources(name: Optional[str] = None,
                           name_contains: Optional[str] = None,
                           name_exclude: Optional[str] = None,
                           name_prefix: Optional[str] = None,
                           name_regexp: Optional[str] = None,
                           name_suffix: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTwingateResourcesResult:
    """
    Resources in Twingate represent servers on the private network that clients can connect to. Resources can be defined by IP, CIDR range, FQDN, or DNS zone. For more information, see the Twingate [documentation](https://docs.twingate.com/docs/resources-and-access-nodes).

    ## Example Usage

    <!--Start PulumiCodeChooser -->
    ```python
    import pulumi
    import pulumi_twingate as twingate

    foo = twingate.get_twingate_resources(name="<your resource's name>")
    ```
    <!--End PulumiCodeChooser -->


    :param str name: The name of the Resource
    :param str name_contains: Match when the value exist in the name of the resource.
    :param str name_exclude: Match when the exact value does not exist in the name of the resource.
    :param str name_prefix: The name of the resource must start with the value.
    :param str name_regexp: The regular expression match of the name of the resource.
    :param str name_suffix: The name of the resource must end with the value.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['nameContains'] = name_contains
    __args__['nameExclude'] = name_exclude
    __args__['namePrefix'] = name_prefix
    __args__['nameRegexp'] = name_regexp
    __args__['nameSuffix'] = name_suffix
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('twingate:index/getTwingateResources:getTwingateResources', __args__, opts=opts, typ=GetTwingateResourcesResult).value

    return AwaitableGetTwingateResourcesResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        name_contains=pulumi.get(__ret__, 'name_contains'),
        name_exclude=pulumi.get(__ret__, 'name_exclude'),
        name_prefix=pulumi.get(__ret__, 'name_prefix'),
        name_regexp=pulumi.get(__ret__, 'name_regexp'),
        name_suffix=pulumi.get(__ret__, 'name_suffix'),
        resources=pulumi.get(__ret__, 'resources'))


@_utilities.lift_output_func(get_twingate_resources)
def get_twingate_resources_output(name: Optional[pulumi.Input[Optional[str]]] = None,
                                  name_contains: Optional[pulumi.Input[Optional[str]]] = None,
                                  name_exclude: Optional[pulumi.Input[Optional[str]]] = None,
                                  name_prefix: Optional[pulumi.Input[Optional[str]]] = None,
                                  name_regexp: Optional[pulumi.Input[Optional[str]]] = None,
                                  name_suffix: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTwingateResourcesResult]:
    """
    Resources in Twingate represent servers on the private network that clients can connect to. Resources can be defined by IP, CIDR range, FQDN, or DNS zone. For more information, see the Twingate [documentation](https://docs.twingate.com/docs/resources-and-access-nodes).

    ## Example Usage

    <!--Start PulumiCodeChooser -->
    ```python
    import pulumi
    import pulumi_twingate as twingate

    foo = twingate.get_twingate_resources(name="<your resource's name>")
    ```
    <!--End PulumiCodeChooser -->


    :param str name: The name of the Resource
    :param str name_contains: Match when the value exist in the name of the resource.
    :param str name_exclude: Match when the exact value does not exist in the name of the resource.
    :param str name_prefix: The name of the resource must start with the value.
    :param str name_regexp: The regular expression match of the name of the resource.
    :param str name_suffix: The name of the resource must end with the value.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 api_token: Optional[pulumi.Input[str]] = None,
                 http_max_retry: Optional[pulumi.Input[int]] = None,
                 http_timeout: Optional[pulumi.Input[int]] = None,
                 network: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[str] api_token: The access key for API operations. You can retrieve this from the Twingate Admin Console
               ([documentation](https://docs.twingate.com/docs/api-overview)). Alternatively, this can be specified using the
               TWINGATE_API_TOKEN environment variable.
        :param pulumi.Input[int] http_max_retry: Specifies a retry limit for the http requests made. The default value is 10. Alternatively, this can be specified using
               the TWINGATE_HTTP_MAX_RETRY environment variable
        :param pulumi.Input[int] http_timeout: Specifies a time limit in seconds for the http requests made. The default value is 35 seconds. Alternatively, this can
               be specified using the TWINGATE_HTTP_TIMEOUT environment variable
        :param pulumi.Input[str] network: Your Twingate network ID for API operations. You can find it in the Admin Console URL, for example:
               `autoco.twingate.com`, where `autoco` is your network ID Alternatively, this can be specified using the TWINGATE_NETWORK
               environment variable.
        :param pulumi.Input[str] url: The default is 'twingate.com' This is optional and shouldn't be changed under normal circumstances.
        """
        if api_token is not None:
            pulumi.set(__self__, "api_token", api_token)
        if http_max_retry is not None:
            pulumi.set(__self__, "http_max_retry", http_max_retry)
        if http_timeout is not None:
            pulumi.set(__self__, "http_timeout", http_timeout)
        if network is not None:
            pulumi.set(__self__, "network", network)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="apiToken")
    def api_token(self) -> Optional[pulumi.Input[str]]:
        """
        The access key for API operations. You can retrieve this from the Twingate Admin Console
        ([documentation](https://docs.twingate.com/docs/api-overview)). Alternatively, this can be specified using the
        TWINGATE_API_TOKEN environment variable.
        """
        return pulumi.get(self, "api_token")

    @api_token.setter
    def api_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_token", value)

    @property
    @pulumi.getter(name="httpMaxRetry")
    def http_max_retry(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies a retry limit for the http requests made. The default value is 10. Alternatively, this can be specified using
        the TWINGATE_HTTP_MAX_RETRY environment variable
        """
        return pulumi.get(self, "http_max_retry")

    @http_max_retry.setter
    def http_max_retry(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "http_max_retry", value)

    @property
    @pulumi.getter(name="httpTimeout")
    def http_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies a time limit in seconds for the http requests made. The default value is 35 seconds. Alternatively, this can
        be specified using the TWINGATE_HTTP_TIMEOUT environment variable
        """
        return pulumi.get(self, "http_timeout")

    @http_timeout.setter
    def http_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "http_timeout", value)

    @property
    @pulumi.getter
    def network(self) -> Optional[pulumi.Input[str]]:
        """
        Your Twingate network ID for API operations. You can find it in the Admin Console URL, for example:
        `autoco.twingate.com`, where `autoco` is your network ID Alternatively, this can be specified using the TWINGATE_NETWORK
        environment variable.
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[str]]:
        """
        The default is 'twingate.com' This is optional and shouldn't be changed under normal circumstances.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_token: Optional[pulumi.Input[str]] = None,
                 http_max_retry: Optional[pulumi.Input[int]] = None,
                 http_timeout: Optional[pulumi.Input[int]] = None,
                 network: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The provider type for the twingate package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_token: The access key for API operations. You can retrieve this from the Twingate Admin Console
               ([documentation](https://docs.twingate.com/docs/api-overview)). Alternatively, this can be specified using the
               TWINGATE_API_TOKEN environment variable.
        :param pulumi.Input[int] http_max_retry: Specifies a retry limit for the http requests made. The default value is 10. Alternatively, this can be specified using
               the TWINGATE_HTTP_MAX_RETRY environment variable
        :param pulumi.Input[int] http_timeout: Specifies a time limit in seconds for the http requests made. The default value is 35 seconds. Alternatively, this can
               be specified using the TWINGATE_HTTP_TIMEOUT environment variable
        :param pulumi.Input[str] network: Your Twingate network ID for API operations. You can find it in the Admin Console URL, for example:
               `autoco.twingate.com`, where `autoco` is your network ID Alternatively, this can be specified using the TWINGATE_NETWORK
               environment variable.
        :param pulumi.Input[str] url: The default is 'twingate.com' This is optional and shouldn't be changed under normal circumstances.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the twingate package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_token: Optional[pulumi.Input[str]] = None,
                 http_max_retry: Optional[pulumi.Input[int]] = None,
                 http_timeout: Optional[pulumi.Input[int]] = None,
                 network: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["api_token"] = None if api_token is None else pulumi.Output.secret(api_token)
            __props__.__dict__["http_max_retry"] = pulumi.Output.from_input(http_max_retry).apply(pulumi.runtime.to_json) if http_max_retry is not None else None
            __props__.__dict__["http_timeout"] = pulumi.Output.from_input(http_timeout).apply(pulumi.runtime.to_json) if http_timeout is not None else None
            __props__.__dict__["network"] = network
            __props__.__dict__["url"] = url
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["apiToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Provider, __self__).__init__(
            'twingate',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter(name="apiToken")
    def api_token(self) -> pulumi.Output[Optional[str]]:
        """
        The access key for API operations. You can retrieve this from the Twingate Admin Console
        ([documentation](https://docs.twingate.com/docs/api-overview)). Alternatively, this can be specified using the
        TWINGATE_API_TOKEN environment variable.
        """
        return pulumi.get(self, "api_token")

    @property
    @pulumi.getter
    def network(self) -> pulumi.Output[Optional[str]]:
        """
        Your Twingate network ID for API operations. You can find it in the Admin Console URL, for example:
        `autoco.twingate.com`, where `autoco` is your network ID Alternatively, this can be specified using the TWINGATE_NETWORK
        environment variable.
        """
        return pulumi.get(self, "network")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[Optional[str]]:
        """
        The default is 'twingate.com' This is optional and shouldn't be changed under normal circumstances.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['TwingateUserArgs', 'TwingateUser']

@pulumi.input_type
class TwingateUserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 first_name: Optional[pulumi.Input[str]] = None,
                 is_active: Optional[pulumi.Input[bool]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 send_invite: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a TwingateUser resource.
        :param pulumi.Input[str] email: The User's email address
        :param pulumi.Input[str] first_name: The User's first name
        :param pulumi.Input[bool] is_active: Determines whether the User is active or not. Inactive users will be not able to sign in.
        :param pulumi.Input[str] last_name: The User's last name
        :param pulumi.Input[str] role: Determines the User's role. Either ADMIN, DEVOPS, SUPPORT or MEMBER.
        :param pulumi.Input[bool] send_invite: Determines whether to send an email invitation to the User. True by default.
        """
        pulumi.set(__self__, "email", email)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if is_active is not None:
            pulumi.set(__self__, "is_active", is_active)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if send_invite is not None:
            pulumi.set(__self__, "send_invite", send_invite)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        """
        The User's email address
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[str]]:
        """
        The User's first name
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="isActive")
    def is_active(self) -> Optional[pulumi.Input[bool]]:
        """
        Determines whether the User is active or not. Inactive users will be not able to sign in.
        """
        return pulumi.get(self, "is_active")

    @is_active.setter
    def is_active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_active", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[str]]:
        """
        The User's last name
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_name", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        Determines the User's role. Either ADMIN, DEVOPS, SUPPORT or MEMBER.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter(name="sendInvite")
    def send_invite(self) -> Optional[pulumi.Input[bool]]:
        """
        Determines whether to send an email invitation to the User. True by default.
        """
        return pulumi.get(self, "send_invite")

    @send_invite.setter
    def send_invite(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_invite", value)


@pulumi.input_type
class _TwingateUserState:
    def __init__(__self__, *,
                 email: Optional[pulumi.Input[str]] = None,
                 first_name: Optional[pulumi.Input[str]] = None,
                 is_active: Optional[pulumi.Input[bool]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 send_invite: Optional[pulumi.Input[bool]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering TwingateUser resources.
        :param pulumi.Input[str] email: The User's email address
        :param pulumi.Input[str] first_name: The User's first name
        :param pulumi.Input[bool] is_active: Determines whether the User is active or not. Inactive users will be not able to sign in.
        :param pulumi.Input[str] last_name: The User's last name
        :param pulumi.Input[str] role: Determines the User's role. Either ADMIN, DEVOPS, SUPPORT or MEMBER.
        :param pulumi.Input[bool] send_invite: Determines whether to send an email invitation to the User. True by default.
        :param pulumi.Input[str] type: Indicates the User's type. Either MANUAL or SYNCED.
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if is_active is not None:
            pulumi.set(__self__, "is_active", is_active)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if send_invite is not None:
            pulumi.set(__self__, "send_invite", send_invite)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[str]]:
        """
        The User's email address
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[str]]:
        """
        The User's first name
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="isActive")
    def is_active(self) -> Optional[pulumi.Input[bool]]:
        """
        Determines whether the User is active or not. Inactive users will be not able to sign in.
        """
        return pulumi.get(self, "is_active")

    @is_active.setter
    def is_active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_active", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[str]]:
        """
        The User's last name
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_name", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        Determines the User's role. Either ADMIN, DEVOPS, SUPPORT or MEMBER.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter(name="sendInvite")
    def send_invite(self) -> Optional[pulumi.Input[bool]]:
        """
        Determines whether to send an email invitation to the User. True by default.
        """
        return pulumi.get(self, "send_invite")

    @send_invite.setter
    def send_invite(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "send_invite", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates the User's type. Either MANUAL or SYNCED.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class TwingateUser(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 first_name: Optional[pulumi.Input[str]] = None,
                 is_active: Optional[pulumi.Input[bool]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 send_invite: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Users provides different levels of write capabilities across the Twingate Admin Console. For more information, see Twingate's [documentation](https://www.twingate.com/docs/users).

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import emailbob_twingate as twingate

        user = twingate.TwingateUser("user",
            email="sample@company.com",
            first_name="Twin",
            last_name="Gate",
            role="DEVOPS",
            send_invite=True)
        ```
        <!--End PulumiCodeChooser -->

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: The User's email address
        :param pulumi.Input[str] first_name: The User's first name
        :param pulumi.Input[bool] is_active: Determines whether the User is active or not. Inactive users will be not able to sign in.
        :param pulumi.Input[str] last_name: The User's last name
        :param pulumi.Input[str] role: Determines the User's role. Either ADMIN, DEVOPS, SUPPORT or MEMBER.
        :param pulumi.Input[bool] send_invite: Determines whether to send an email invitation to the User. True by default.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TwingateUserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Users provides different levels of write capabilities across the Twingate Admin Console. For more information, see Twingate's [documentation](https://www.twingate.com/docs/users).

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import emailbob_twingate as twingate

        user = twingate.TwingateUser("user",
            email="sample@company.com",
            first_name="Twin",
            last_name="Gate",
            role="DEVOPS",
            send_invite=True)
        ```
        <!--End PulumiCodeChooser -->

        :param str resource_name: The name of the resource.
        :param TwingateUserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TwingateUserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 first_name: Optional[pulumi.Input[str]] = None,
                 is_active: Optional[pulumi.Input[bool]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 send_invite: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TwingateUserArgs.__new__(TwingateUserArgs)

            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["first_name"] = first_name
            __props__.__dict__["is_active"] = is_active
            __props__.__dict__["last_name"] = last_name
            __props__.__dict__["role"] = role
            __props__.__dict__["send_invite"] = send_invite
            __props__.__dict__["type"] = None
        super(TwingateUser, __self__).__init__(
            'twingate:index/twingateUser:TwingateUser',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            email: Optional[pulumi.Input[str]] = None,
            first_name: Optional[pulumi.Input[str]] = None,
            is_active: Optional[pulumi.Input[bool]] = None,
            last_name: Optional[pulumi.Input[str]] = None,
            role: Optional[pulumi.Input[str]] = None,
            send_invite: Optional[pulumi.Input[bool]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'TwingateUser':
        """
        Get an existing TwingateUser resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: The User's email address
        :param pulumi.Input[str] first_name: The User's first name
        :param pulumi.Input[bool] is_active: Determines whether the User is active or not. Inactive users will be not able to sign in.
        :param pulumi.Input[str] last_name: The User's last name
        :param pulumi.Input[str] role: Determines the User's role. Either ADMIN, DEVOPS, SUPPORT or MEMBER.
        :param pulumi.Input[bool] send_invite: Determines whether to send an email invitation to the User. True by default.
        :param pulumi.Input[str] type: Indicates the User's type. Either MANUAL or SYNCED.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TwingateUserState.__new__(_TwingateUserState)

        __props__.__dict__["email"] = email
        __props__.__dict__["first_name"] = first_name
        __props__.__dict__["is_active"] = is_active
        __props__.__dict__["last_name"] = last_name
        __props__.__dict__["role"] = role
        __props__.__dict__["send_invite"] = send_invite
        __props__.__dict__["type"] = type
        return TwingateUser(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[str]:
        """
        The User's email address
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> pulumi.Output[str]:
        """
        The User's first name
        """
        return pulumi.get(self, "first_name")

    @property
    @pulumi.getter(name="isActive")
    def is_active(self) -> pulumi.Output[bool]:
        """
        Determines whether the User is active or not. Inactive users will be not able to sign in.
        """
        return pulumi.get(self, "is_active")

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> pulumi.Output[str]:
        """
        The User's last name
        """
        return pulumi.get(self, "last_name")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[str]:
        """
        Determines the User's role. Either ADMIN, DEVOPS, SUPPORT or MEMBER.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter(name="sendInvite")
    def send_invite(self) -> pulumi.Output[bool]:
        """
        Determines whether to send an email invitation to the User. True by default.
        """
        return pulumi.get(self, "send_invite")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        Indicates the User's type. Either MANUAL or SYNCED.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['TwingateGroupArgs', 'TwingateGroup']

@pulumi.input_type
class TwingateGroupArgs:
    def __init__(__self__, *,
                 is_authoritative: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_policy_id: Optional[pulumi.Input[str]] = None,
                 user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a TwingateGroup resource.
        :param pulumi.Input[bool] is_authoritative: Determines whether User assignments to this Group will override any existing assignments. Default is `true`. If set to
               `false`, assignments made outside of Terraform will be ignored.
        :param pulumi.Input[str] name: The name of the group
        :param pulumi.Input[str] security_policy_id: Defines which Security Policy applies to this Group. The Security Policy ID can be obtained from the `get_twingate_security_policy` and `get_twingate_security_policies` data sources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] user_ids: List of User IDs that have permission to access the Group.
        """
        if is_authoritative is not None:
            pulumi.set(__self__, "is_authoritative", is_authoritative)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if security_policy_id is not None:
            pulumi.set(__self__, "security_policy_id", security_policy_id)
        if user_ids is not None:
            pulumi.set(__self__, "user_ids", user_ids)

    @property
    @pulumi.getter(name="isAuthoritative")
    def is_authoritative(self) -> Optional[pulumi.Input[bool]]:
        """
        Determines whether User assignments to this Group will override any existing assignments. Default is `true`. If set to
        `false`, assignments made outside of Terraform will be ignored.
        """
        return pulumi.get(self, "is_authoritative")

    @is_authoritative.setter
    def is_authoritative(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_authoritative", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the group
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> Optional[pulumi.Input[str]]:
        """
        Defines which Security Policy applies to this Group. The Security Policy ID can be obtained from the `get_twingate_security_policy` and `get_twingate_security_policies` data sources.
        """
        return pulumi.get(self, "security_policy_id")

    @security_policy_id.setter
    def security_policy_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_policy_id", value)

    @property
    @pulumi.getter(name="userIds")
    def user_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of User IDs that have permission to access the Group.
        """
        return pulumi.get(self, "user_ids")

    @user_ids.setter
    def user_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "user_ids", value)


@pulumi.input_type
class _TwingateGroupState:
    def __init__(__self__, *,
                 is_authoritative: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_policy_id: Optional[pulumi.Input[str]] = None,
                 user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering TwingateGroup resources.
        :param pulumi.Input[bool] is_authoritative: Determines whether User assignments to this Group will override any existing assignments. Default is `true`. If set to
               `false`, assignments made outside of Terraform will be ignored.
        :param pulumi.Input[str] name: The name of the group
        :param pulumi.Input[str] security_policy_id: Defines which Security Policy applies to this Group. The Security Policy ID can be obtained from the `get_twingate_security_policy` and `get_twingate_security_policies` data sources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] user_ids: List of User IDs that have permission to access the Group.
        """
        if is_authoritative is not None:
            pulumi.set(__self__, "is_authoritative", is_authoritative)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if security_policy_id is not None:
            pulumi.set(__self__, "security_policy_id", security_policy_id)
        if user_ids is not None:
            pulumi.set(__self__, "user_ids", user_ids)

    @property
    @pulumi.getter(name="isAuthoritative")
    def is_authoritative(self) -> Optional[pulumi.Input[bool]]:
        """
        Determines whether User assignments to this Group will override any existing assignments. Default is `true`. If set to
        `false`, assignments made outside of Terraform will be ignored.
        """
        return pulumi.get(self, "is_authoritative")

    @is_authoritative.setter
    def is_authoritative(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_authoritative", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the group
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> Optional[pulumi.Input[str]]:
        """
        Defines which Security Policy applies to this Group. The Security Policy ID can be obtained from the `get_twingate_security_policy` and `get_twingate_security_policies` data sources.
        """
        return pulumi.get(self, "security_policy_id")

    @security_policy_id.setter
    def security_policy_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_policy_id", value)

    @property
    @pulumi.getter(name="userIds")
    def user_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of User IDs that have permission to access the Group.
        """
        return pulumi.get(self, "user_ids")

    @user_ids.setter
    def user_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "user_ids", value)


class TwingateGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_authoritative: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_policy_id: Optional[pulumi.Input[str]] = None,
                 user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Groups are how users are authorized to access Resources. For more information, see Twingate's [documentation](https://docs.twingate.com/docs/groups).

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import emailbob_twingate as twingate

        aws = twingate.TwingateGroup("aws")
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        ```sh
        $ pulumi import twingate:index/twingateGroup:TwingateGroup aws R3JvdXA6MzQ4OTE=
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] is_authoritative: Determines whether User assignments to this Group will override any existing assignments. Default is `true`. If set to
               `false`, assignments made outside of Terraform will be ignored.
        :param pulumi.Input[str] name: The name of the group
        :param pulumi.Input[str] security_policy_id: Defines which Security Policy applies to this Group. The Security Policy ID can be obtained from the `get_twingate_security_policy` and `get_twingate_security_policies` data sources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] user_ids: List of User IDs that have permission to access the Group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[TwingateGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Groups are how users are authorized to access Resources. For more information, see Twingate's [documentation](https://docs.twingate.com/docs/groups).

        ## Example Usage

        <!--Start PulumiCodeChooser -->
        ```python
        import pulumi
        import emailbob_twingate as twingate

        aws = twingate.TwingateGroup("aws")
        ```
        <!--End PulumiCodeChooser -->

        ## Import

        ```sh
        $ pulumi import twingate:index/twingateGroup:TwingateGroup aws R3JvdXA6MzQ4OTE=
        ```

        :param str resource_name: The name of the resource.
        :param TwingateGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TwingateGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_authoritative: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_policy_id: Optional[pulumi.Input[str]] = None,
                 user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TwingateGroupArgs.__new__(TwingateGroupArgs)

            __props__.__dict__["is_authoritative"] = is_authoritative
            __props__.__dict__["name"] = name
            __props__.__dict__["security_policy_id"] = security_policy_id
            __props__.__dict__["user_ids"] = user_ids
        super(TwingateGroup, __self__).__init__(
            'twingate:index/twingateGroup:TwingateGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            is_authoritative: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            security_policy_id: Optional[pulumi.Input[str]] = None,
            user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'TwingateGroup':
        """
        Get an existing TwingateGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] is_authoritative: Determines whether User assignments to this Group will override any existing assignments. Default is `true`. If set to
               `false`, assignments made outside of Terraform will be ignored.
        :param pulumi.Input[str] name: The name of the group
        :param pulumi.Input[str] security_policy_id: Defines which Security Policy applies to this Group. The Security Policy ID can be obtained from the `get_twingate_security_policy` and `get_twingate_security_policies` data sources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] user_ids: List of User IDs that have permission to access the Group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TwingateGroupState.__new__(_TwingateGroupState)

        __props__.__dict__["is_authoritative"] = is_authoritative
        __props__.__dict__["name"] = name
        __props__.__dict__["security_policy_id"] = security_policy_id
        __props__.__dict__["user_ids"] = user_ids
        return TwingateGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="isAuthoritative")
    def is_authoritative(self) -> pulumi.Output[bool]:
        """
        Determines whether User assignments to this Group will override any existing assignments. Default is `true`. If set to
        `false`, assignments made outside of Terraform will be ignored.
        """
        return pulumi.get(self, "is_authoritative")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the group
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> pulumi.Output[str]:
        """
        Defines which Security Policy applies to this Group. The Security Policy ID can be obtained from the `get_twingate_security_policy` and `get_twingate_security_policies` data sources.
        """
        return pulumi.get(self, "security_policy_id")

    @property
    @pulumi.getter(name="userIds")
    def user_ids(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of User IDs that have permission to access the Group.
        """
        return pulumi.get(self, "user_ids")

